# The Official Pawn-Pay API Client 
A sonic interface link with tactical graviton field assist to detect and correct 
anomalies in a Pawn software's linear subspace polarity emitters.

![If only I could be so grossly incandescent](pawn_pay/docs/readme.svg)

## Supported Softwares
|  Software  |         Developer        |    Support Level   |
| :--------: | :----------------------: | :----------------: |
| [PawnMaster](https://github.com/PawnPaymentSolutions/PawnMaster) | DataAge Business Systems | Full Support |
| [PawnDex](https://github.com/PawnPaymentSolutions/PawnDex)   |       Teknon, Inc.       | Upload Only |

## Status
|  Feature                   | Written | Tested | Notes |
| :------------------------- | :-----: | :----: | :---: |
|  👥                        |         |        |       |
| Creates Customers          |    ✅   |   ✅   |       |
| Lists Customers            |    ✅   |   ✅   |       |
| Gets Single Customer       |    ✅   |   ✅   |       |
| Updates Single Customer    |    ✅   |   ✅   |       |
| Batch Updates Customers    |    ✅   |   ✅   |       |
|  📋                        |         |        |       |
| Creates Tickets            |    ✅   |   ✅   |       |
| Lists Tickets              |    ✅   |   ✅   |       |
| Gets Single Ticket         |    ✅   |   ✅   |       |
| Updates Single Ticket      |    ✅   |   ✅   |       |
| Batch Updates Tickets      |    ✅   |   ✅   |       |
|  🧾                        |         |        |       |
| Gets New Payments          |    ✅   |   ✅   |       |
| Marks Payments Recorded    |    ✅   |   ✅   |       |
| Gets Payments Since `Date` |    ✅   |   ✅   |       |
| Gets Single Payment        |    ✅   |   ✅   |       |
| Refunds Payments           |    ✅️   |   ⁉️   | The refund payment function *should* work, but isn't testable outside of production |

## Usage
```text
The lower photonic particle isotope control system has gone pear-shaped,
resulting in a chain reaction in the upper plasma warp field emitter.
```

### Included Helper Methods
See the [Helpers Read Me](pawn_pay/helpers/README.md "Filled with stuff and things")
